#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# password_dialog.pyw
# 
# the user should give us a password
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright 2013-2014 X-Net and AIT Austrian Institute of Technology
# 
# 
#     X-Net Services GmbH
#     Elisabethstrasse 1
#     4020 Linz
#     AUSTRIA
#     https://www.x-net.at
# 
#     AIT Austrian Institute of Technology
#     Donau City Strasse 1
#     1220 Wien
#     AUSTRIA
#     http://www.ait.ac.at
# 
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

if sys.platform == 'win32' or sys.platform == 'cygwin':
    import win32api
    import win32con
    import win32gui

from PyQt4 import QtCore
from PyQt4 import QtGui

from ui_PasswordDialog import Ui_PasswordDialog 
from about_dialog import AboutDialog


# ------------------------------------------------------------
# code


class PasswordDialog(QtGui.QDialog):

    """A dialog for letting the user type in a password"""

    def __init__(self, user_text = 'Please provide an approbitate password to proceed:'):

        QtGui.QDialog.__init__(self)

        # setup the user interface
        self.ui = Ui_PasswordDialog()
        self.ui.setupUi(self)
    
        # local members
        self._about_dialog = AboutDialog()

        # connectors
        self.ui.lblText.setText(user_text)
        self.ui.btnAbout.clicked.connect(self.clicked_about)
        self.ui.btnCancel.clicked.connect(self.reject)
        self.ui.btnOk.clicked.connect(self.clicked_ok)

        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)

        t = QtCore.QTimer(self)
        t.timeout.connect(self.force_foreground)
        t.setInterval(0)
        t.setSingleShot(True)
        t.start()
 

    def clicked_about(self):

        """About button has been clicked."""
        self._about_dialog.show()


    def clicked_ok(self):
        
        """Ok button has been clicked."""
        sys.stdout.write('{ ')
        sys.stdout.write('"password": "')
        sys.stdout.write(self.ui.edtPassword.text())
        sys.stdout.write('" ')
        sys.stdout.write('}\n')
        self.accept()


    def force_foreground(self):

        """Force ourselves into foreground"""
        if sys.platform == 'win32' or sys.platform == 'cygwin':
            w = self
            while not w.nativeParentWidget() is None:
                w = w.nativeParentWidget()
            win32gui.BringWindowToTop(int(w.effectiveWinId()))
            win32gui.SetForegroundWindow(int(w.effectiveWinId()))


    def set_user_text(user_text):

        """Set a text to explain which password we need."""
        self.ui.lblText.setText(user_text)


if __name__ == "__main__":
    if sys.platform == 'win32' or sys.platform == 'cygwin':
        win32gui.SystemParametersInfo(win32con.SPI_SETFOREGROUNDLOCKTIMEOUT, 0, win32con.SPIF_SENDWININICHANGE | win32con.SPIF_UPDATEINIFILE)
    a = QtGui.QApplication(sys.argv)
    d = PasswordDialog()
    d.show()
    sys.exit(a.exec_())     

